#
# Hardware settings for Teclast F5 10" Laptop
# NixOS @ sda2
#
# flake.nix
#  └─ ./hosts
#      └─ ./laptop
#          └─ hardware-configuration.nix *
#
# Do not modify this file!  It was generated by ‘nixos-generate-config’
# and may be overwritten by future invocations.  Please make changes
# to /etc/nixos/configuration.nix instead.
{ config, lib, pkgs, modulesPath, ... }:

{
  imports =
    [ (modulesPath + "/installer/scan/not-detected.nix")] ++
      [( import ../../modules/hardware/backup.nix )];

  boot.initrd.availableKernelModules = [ "xhci_pci" "ahci" "nvme" "usb_storage" "usbhid" "sd_mod" ];
  boot.initrd.kernelModules = [ "vfio_pci" "vfio" "vfio_iommu_type1" ];
  boot.kernelModules = [ "kvm-amd" "nct6775" ];
  boot.extraModulePackages = [ ];
  boot.tmp.useTmpfs = false;
  boot.tmp.cleanOnBoot = true;
  zramSwap.enable = true;

  services.btrfs.autoScrub = {
    enable = true;
    interval = "monthly";
    fileSystems = [
      "/"
    ];
  };

  services.btrbk = {
      extraPackages = [ pkgs.lz4 pkgs.mbuffer ];
      instances = {
          hf = {
              onCalendar = "hourly";
              settings = {
                  incremental = "yes";
                  snapshot_create = "ondemand";
                  snapshot_dir = "@snapshots";
                  timestamp_format = "long";

                  snapshot_preserve = "2m 2w 5d 5h";
                  snapshot_preserve_min = "latest";
                
                  volume =  {
                      "/mnt/snapshots/root" = {
                          snapshot_create = "always";
                          subvolume = {
                              "@home" = {};
                          };
                      };
                  };
              };
          };
          bak = {
              onCalendar = "daily";
              settings = {
	          stream_buffer = "256m";
                  stream_compress = "lz4";
                  incremental = "yes";
                  snapshot_create = "no";
                  snapshot_dir = "@snapshots";
                  timestamp_format = "long";

                  snapshot_preserve_min = "all";
                  target_preserve_min = "no";
                  target_preserve = "2m 4w 3d";

                  ssh_identity = "/etc/btrbk/ssh/id_ed25519_btrbk_nas";
                  ssh_user = "btrbk";
                
                  volume =  {
                      "/mnt/snapshots/root" = {
                          subvolume = {
                              "@home" = {};
                          };
		          target = "ssh://jupiter.home.opel-online.de:2220/mnt/snapshots/Mars/@snapshots/@hades";
                      };
                  };
	      };
	  };
      };
  };

  systemd.timers = {
      btrbk-bak = {
          after = [ "network-online.target" ];
          requires = [ "network-online.target" ];
      };
  };

  fileSystems."/" =
    { device = "/dev/disk/by-id/nvme-ADATA_SX8200PNP_2J3320119186-part2";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@,discard=async" ];
    };

  fileSystems."/home" =
    { device = "/dev/disk/by-id/nvme-ADATA_SX8200PNP_2J3320119186-part2";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@home,discard=async" ];
    };

  fileSystems."/srv" =
    { device = "/dev/disk/by-id/nvme-ADATA_SX8200PNP_2J3320119186-part2";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@srv,discard=async" ];
    };

  fileSystems."/nix" =
    { device = "/dev/disk/by-id/nvme-ADATA_SX8200PNP_2J3320119186-part2";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@nix,discard=async" ];
    };

  fileSystems."/swap" =
    { device = "/dev/disk/by-id/nvme-ADATA_SX8200PNP_2J3320119186-part2";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvol=@swap,discard=async" ];
    };

  fileSystems."/mnt/snapshots/root" =
    { device = "/dev/disk/by-id/nvme-ADATA_SX8200PNP_2J3320119186-part2";
      fsType = "btrfs";
      options = [ "compress=zstd,space_cache=v2,ssd,noatime,subvolid=5,discard=async" ];
    };

  fileSystems."/boot" =
    { device = "/dev/disk/by-id/nvme-ADATA_SX8200PNP_2J3320119186-part1";
      fsType = "vfat";
    };

  fileSystems."/mnt/Pluto" =
    { device = "jupiter:/Pluto";
      fsType = "nfs";
      options = [ "noauto,users,x-systemd.automount,x-systemd.device-timeout=10,soft,timeo=14,x-systemd.idle-timeout=1min,sec=sys,exec,nfsvers=4.2" ];
    };

  fileSystems."/mnt/Mars" =
    { device = "jupiter:/Mars";
      fsType = "nfs";
      options = [ "noauto,users,x-systemd.automount,x-systemd.device-timeout=10,soft,timeo=14,x-systemd.idle-timeout=1min,sec=sys,exec,nfsvers=4.2" ];
    };


  swapDevices = [ { device = "/swap/swapfile"; } ];
  
  networking = {
    useDHCP = false;                        # Deprecated
    hostName = "hades";
    networkmanager = {
      enable = true;
    };
    firewall = {
      enable = true;
      allowedUDPPorts = [ 24727 ];
      allowedTCPPorts = [ 24727 ];
    };
  };

#  systemd.network = {
#      enable = true;
#      networks = {
#          "10-lan" = {
#              matchConfig.Name = "eno1";
#              ntp = [ "192.168.2.1" ];
#              domains = [ "home.opel-online.de" ];
#              networkConfig = {
#                DHCP = "yes";
#                IPv6AcceptRA = true;
#              };
#          };
#      };
#  };

  hardware.cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
  #powerManagement.powertop.enable = true;
  powerManagement = {
    scsiLinkPolicy = "med_power_with_dipm";
  };
}
